socketopts

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package socketopts configures carrier sockets before connection establishment.

Index

Constants

This section is empty.

Variables

var (
	// ErrUnsupportedMark indicates a nonzero firewall mark on an unsupported platform.
	ErrUnsupportedMark = errors.New("socket firewall mark is unsupported")
)

Functions

func NewDialer

func NewDialer(base *net.Dialer, mark uint32) (*net.Dialer, error)

NewDialer clones base and applies mark before every carrier and resolver socket connection.

Types

This section is empty.

Jump to